/* 
 * File:   CC2500Anaren.h
 * Author: michal.brazda
 *
 * Created on 15. ?ervna 2016, 14:10
 */

#ifndef CC2500ANAREN_H
#define	CC2500ANAREN_H

#ifdef	__cplusplus
extern "C" {
#endif

#include <stdio.h>
#include <stdbool.h>    
#include "CC2500_registers.h"
#include "stm32f4xx_hal.h"
    
#define CC2500_SPI_TIMEOUT      500
 
    
#define READ_SINGLE  0x80
#define READ_BURST  0xC0
#define WRITE_SINGLE  0x00
#define WRITE_BURST  0x40

#define CC2500_GDO0  0x00
#define CC2500_GDO1  0x01 
#define CC2500_GDO2  0x02  
    
#define GDO_RXFIFO_ABOVE_THR_OR_END_OF_PACKET 0x00
#define GDO_TXFIFO_ABOVE_THR_DEASERT_BELLOW   0x02
    
#define CAL_WRITE 0x00
#define CAL_READ  0x01
    
//-------------------------------------------------------------------------------------------------------
// CC2400_STATUS is a data structure which contains status register value
typedef union {

    unsigned char StatusByte;

    struct {
        unsigned FIFO_AVAILABLE :4;
        unsigned STATE          :3;
        unsigned ChipRDY        :1;
   } StatusBits;

} CC2500_STATUS;



typedef enum
{
    CC2500_IDLE                   = 0x00,
    CC2500_RX_ENABLED             = 0x01,
    TX_MODE_ENABLED               = 0x02,
    FSTXON                        = 0x03,
    CC2500_CALIBRATE              = 0x04,
    SETTLING                      = 0x05,
    RX_FIFO_OVERFLOW              = 0x06,
    TX_FIFO_UNDERFLOW             = 0x07,
    CC2500_PACKET_RECEIVEING      = 0x08,
    CC2500_FINISHING_TRANSMISSON  = 0x09           
} STATE_Definitions_Enum;


uint8_t CC2500_SPI_Comm( SPI_HandleTypeDef* hspi, uint8_t* TxData, uint8_t* RxData, uint16_t MSize);
uint8_t CC2500_SPI_Comm_DMA( SPI_HandleTypeDef* hspi, uint8_t* TxData, uint8_t* RxData, uint16_t MSize);

bool CC2500_Init( SPI_HandleTypeDef* hspi );
/*******************************************************************************
 *CC2500_Status_Update - vrati aktualni hodnotu status registru 
 * vstup    none 
 * vystup   stav status registru 
 ******************************************************************************/
uint8_t CC2500_Status_Update( SPI_HandleTypeDef* hspi );
/*******************************************************************************
 * CC2500_Write_Register - zapis nove hodnoty do registru radia
 * vstup    reg - enum registru urceneho pro zapis 
 *          data - nova hodnota registru 
 * vystup   true - data byla zapsana 
 *          flase - neplatny nazev registru nebo pokus o pristup do read only 
 *                  registru
*******************************************************************************/
bool CC2500_Write_Register(SPI_HandleTypeDef* hspi, CC2500Registers_Enum Reg, uint8_t Data);
/*******************************************************************************
 * CC2500_Write_FIFO_Burst - yapis pole dat do FIFO 
 * vstup    RadioType - RADIO_MICROE or RADIO_ANAREN
 *          Data - pointer na pole dat
 *          data - delka datove oblasti  
 *******************************************************************************/
uint8_t CC2500_Read_Register(SPI_HandleTypeDef* hspi, CC2500Registers_Enum reg);

void    CC2500_Send_Data(uint8_t*  Data, uint8_t DataLen);
void    CC2500_TX_Enable(SPI_HandleTypeDef* hspi);
void    CC2500_RX_Enable(SPI_HandleTypeDef* hspi);
void    CC2500_TXRX_Off(SPI_HandleTypeDef* hspi);
uint8_t    CC2500_Get_State(SPI_HandleTypeDef* hspi, uint8_t read_write);

/*******************************************************************************
 * CC2500_SendVariablePacket - odesle data o delce PacketLen z &Data
 * vstup    ukazatel na pole data 
 *          Delka pole 
 * vystup   NA
 * 
 *          JE TREBA UMISTIT DO ISR PRO GD0 s parametrem PacketLen -1 !!!
 * 
*******************************************************************************/
uint8_t CC2500_SendVariablePacket( SPI_HandleTypeDef* hspi, uint8_t *Data, int8_t PacketLen);
/*******************************************************************************
 * CC2500_ReceiveVariablePacketMasterModul - vycita data z FIFO
 * vstup    slouzi pro urceni zdroje volani 
 * vystup   NA
 * 
 *          JE TREBA UMISTIT DO ISR PRO GD0 s parametrem CC2500_GDO0 !!!
 *          JE TREBA UMISTIT DO ISR PRO GD2 s parametrem CC2500_GDO2 !!!
 * 
*******************************************************************************/
uint8_t CC2500_ReceiveVariablePacketMastermodul( SPI_HandleTypeDef* hspi,  uint8_t GDO_source);

/*******************************************************************************
 * CC2500_ReceiveVariablePacketWeapon - vycita data z FIFO
 * vstup    slouzi pro urceni zdroje volani 
 * vystup   NA
 * 
 *          JE TREBA UMISTIT DO ISR PRO GD0 s parametrem CC2500_GDO0 !!!
 *          JE TREBA UMISTIT DO ISR PRO GD2 s parametrem CC2500_GDO2 !!!
 * 
*******************************************************************************/
uint8_t CC2500_ReceiveVariablePacketWeapon(SPI_HandleTypeDef* hspi,  uint8_t GDO_source );
/*******************************************************************************
 * VariablePacketSent - vola se pri odeslan paketu
 * vstup    NA
 * vystup   NA
 * 
 *          JE TREBA UMISTIT DO ISR PRO GD2!!!
 *          
 *******************************************************************************/
void CC2500_VariablePacketSent(void);
/* CC2500_Channel_Change zmeni kanal a nahraje kalibraci kanalu
 * vstup    Channel
 * vystup   NA
 */
void CC2500_Channel_Change(SPI_HandleTypeDef* hspi, uint8_t Channel);
void CC2500_Measure_Background(uint8_t *dBm);
bool CC2500_CalibrateFrequencies(SPI_HandleTypeDef* hspi);
bool CC2500_CalibrateFrequency(SPI_HandleTypeDef* hspi, uint8_t channel, uint8_t readwrite);
uint8_t CC2500_ReadReceivedPacket(uint8_t *Data);
uint8_t CC2500_Reset( SPI_HandleTypeDef* hspi );
void Wait_undef(uint32_t time);

void RegisterVariablePacketSentCallback(void (*PacketSentCallback)(void));


//void Test_CS( void );
void CC2500_test(void);

// private functions 
static uint8_t cc2500_Write_Byte_No_CS(uint8_t Byte);
/*******************************************************************************
 * CC2500_Send_Strobe_Command - posle strobe command radiu
 * vstup    reg - enum registru urceneho pro cteni 
 * vystup   aktualni hodnota registru 
*******************************************************************************/
uint8_t CC2500_Send_Strobe_Command(SPI_HandleTypeDef* hspi, CC2500StrobeCommands_Enum Command);





#ifdef	__cplusplus
}
#endif

#endif	/* CC2500ANAREN_H */

