

#include "CC2500.h"

#include <string.h>

//#include "peripheral/ports/plib_ports.h"
//#include "system/console/sys_console.h"
//#include "system/int/sys_int.h"

//#define anaren2
//#ifndef anaren2
//#define CC2500_CS_MICROE_PIN    PORTS_BIT_POS_4
//#define CC2500_CS_MICROE_PORT   PORT_CHANNEL_C
//#else
//#define CC2500_CS_MICROE_PIN    PORTS_BIT_POS_1
//#define CC2500_CS_MICROE_PORT   PORT_CHANNEL_D
//#endif

//#define CS_MICROE_ENABLE() PLIB_PORTS_PinClear(PORTS_ID_0, CC2500_CS_MICROE_PORT, CC2500_CS_MICROE_PIN )    
//#define CS_MICROE_DISABLE() PLIB_PORTS_PinSet(PORTS_ID_0, CC2500_CS_MICROE_PORT, CC2500_CS_MICROE_PIN )



#define CC2500_CS_ENABLE() HAL_GPIO_WritePin(SPI3_CS_GPIO_Port,SPI3_CS_Pin,GPIO_PIN_RESET) 
#define CC2500_CS_DISABLE() HAL_GPIO_WritePin(SPI3_CS_GPIO_Port,SPI3_CS_Pin,GPIO_PIN_SET)



static uint8_t CC2500_Get_RX_FIFO_Bytes_Available( SPI_HandleTypeDef* hspi );
static uint8_t CC2500_Get_TX_FIFO_Bytes_Available( SPI_HandleTypeDef* hspi );
static void CC2500_Write_PATABLE( SPI_HandleTypeDef* hspi);


void (*VariablePacketSentcallback)(void) = NULL ;
extern void Process_Message(uint8_t* packet, uint8_t length);

static uint8_t TxFIFO[64];
static uint8_t RxFIFO[64];

static volatile bool ThreadSleep = false;

static STATE_Definitions_Enum CC2500Status;

static uint8_t PacketReceivedLen;
//static uint8_t RXBuffer[120];        
static uint8_t StoredCalibration1[256];
static uint8_t StoredCalibration2;
static uint8_t StoredCalibration3;

static volatile uint16_t oldGDO0;
static volatile uint16_t oldGDO2;

        
void Wait_undef(uint32_t time) 
{   
    volatile uint32_t C;
    for (C = 0 ; C <= time; C++ )
    {
        __nop();
    }
    
}

bool HasDelayElapsed(uint32_t Delay)
{
    static uint32_t DelayCounter;
    if (HAL_GetTick() >= DelayCounter)
    {
        if ((HAL_GetTick() - DelayCounter) >= Delay)
        {
            DelayCounter = HAL_GetTick();
            return true;
        }
    }
    else
    {
        if (((0xFFFF - DelayCounter) + HAL_GetTick()) >= Delay)
        {
            DelayCounter = HAL_GetTick();
            return true;
        }
    }

    return false;
}



uint8_t CC2500_SPI_Comm( SPI_HandleTypeDef* hspi, uint8_t* TxData, uint8_t* RxData, uint16_t MSize)
{
    HAL_SPI_StateTypeDef SPI3_state;
    
    SPI3_state = HAL_SPI_GetState(hspi);
    if (SPI3_state == HAL_SPI_STATE_READY)
    {
        CC2500_CS_ENABLE();
        HAL_SPI_TransmitReceive(hspi,TxData,RxData,MSize,1000);
        CC2500_CS_DISABLE();
    }
}

uint8_t CC2500_SPI_Comm_DMA( SPI_HandleTypeDef* hspi, uint8_t* TxData, uint8_t* RxData, uint16_t MSize)
{
    HAL_SPI_StateTypeDef SPI3_state;
    
    SPI3_state = HAL_SPI_GetState(hspi);
    if (SPI3_state == HAL_SPI_STATE_READY)
    {
        CC2500_CS_ENABLE();
        HAL_SPI_TransmitReceive_DMA(hspi,TxData,RxData,MSize);
        return 1;
    }
    return 0;
}


void HAL_SPI_TxRxCpltCallback(SPI_HandleTypeDef *hspi)
{
    uint8_t PacketLen;
    CC2500_CS_DISABLE();
    switch (CC2500Status)
    {
        case CC2500_FINISHING_TRANSMISSON:
        {
          CC2500_TX_Enable(hspi);
//        while (1)
//            CC2500_Status_Update(hspi);
//        uint8_t i;
//        for (i = 0; i<150;i++)
//        {
//            CC2500_Status_Update(hspi);
//        }
        }
        break;
        
        case CC2500_PACKET_RECEIVEING:
        {
          PacketLen = RxFIFO[1];
          if (PacketLen != 4)
          {
              CC2500_RX_Enable(hspi );
          }
          //all data received 
          //process data
          Process_Message(&RxFIFO[2],4);
          CC2500Status = CC2500_IDLE;
        }
        break;
        
        default:
            break;
            
    }
    if (CC2500Status == CC2500_FINISHING_TRANSMISSON)
    {

        
        


        
    }
    //ThreadSleep = false;
    
}


/*******************************************************************************
 * CC2500_Write_Register - Inicializuje vnitrni registry radia podle anaren
 *          specifikace pro certifikaci dostupne v pdf 
 * https://www.anaren.com/sites/default/files/user-manuals/A2500R24x_Users_Manual_0.pdf
 * 
 *   * vstup    reg - enum registru urceneho pro zapis 
 *          data - nova hodnota registru 
 * vystup   true - data byla zapsana 
 *          flase - neplatny nazev registru nebo pokus o pristup do read only 
 *                  registru
*******************************************************************************/
bool CC2500_CalibrateFrequencies(SPI_HandleTypeDef* hspi)
{
    uint16_t i;
    CC2500_STATUS State;
    uint16_t timeout;
    
    for(i=0;i<256;i++)
    {
        timeout = 1000;
        CC2500_Write_Register(hspi, CC2500_CHANNR ,i);
        CC2500_Send_Strobe_Command(hspi, CC2500_STROBE_SCAL);        //0x33
        do
        {
            State.StatusByte = CC2500_Send_Strobe_Command(hspi, CC2500_STROBE_SNOP);
            timeout--;
        }
        while ((State.StatusBits.STATE == CC2500_CALIBRATE) && (timeout !=0));
        if (timeout==0)
        {
            return false;
        }
        
        StoredCalibration1[i]=CC2500_Read_Register(hspi, CC2500_FSCAL1);
        if(i==255)
        {
            StoredCalibration2=CC2500_Read_Register(hspi, CC2500_FSCAL2);
            StoredCalibration3=CC2500_Read_Register(hspi, CC2500_FSCAL3);
        }
    }
    return true;
}

bool CC2500_CalibrateFrequency(SPI_HandleTypeDef* hspi, uint8_t channel, uint8_t readwrite)
{
    CC2500_STATUS State;
    static uint8_t NewChannel;
    static bool CalibrationRead = true;
    
    if(readwrite == CAL_WRITE)
    {
            NewChannel = channel;
            CC2500_Write_Register(hspi, CC2500_CHANNR ,channel);
            CC2500_TXRX_Off(hspi);
            CC2500_Send_Strobe_Command(hspi, CC2500_STROBE_SCAL);        //0x33
            CalibrationRead = false;
            return true;
    }else{
        if (CalibrationRead == false)
        {
            State.StatusByte = CC2500_Send_Strobe_Command(hspi, CC2500_STROBE_SNOP);
            CalibrationRead = true;
            if(State.StatusBits.STATE == CC2500_IDLE)
            {
                StoredCalibration1[NewChannel]=CC2500_Read_Register(hspi, CC2500_FSCAL1);
                StoredCalibration2=CC2500_Read_Register(hspi, CC2500_FSCAL2);
                StoredCalibration3=CC2500_Read_Register(hspi, CC2500_FSCAL3);
                return true;
            }
            return false;
        }
        return false;
    }
}

void CC2500_Channel_Change(SPI_HandleTypeDef* hspi, uint8_t Channel)
{
    //STATE_Definitions_Enum StateTmp;
    //StateTmp = CC2500Status;
    CC2500_TXRX_Off(hspi);
    
    CC2500_Write_Register(hspi, CC2500_CHANNR, Channel);
    CC2500_Write_Register(hspi, CC2500_FSCAL1, StoredCalibration1[Channel]);       //0x25
    CC2500_Write_Register(hspi, CC2500_FSCAL2, StoredCalibration2);                //0x24
    CC2500_Write_Register(hspi, CC2500_FSCAL3, StoredCalibration3);                //0x23
}

bool CC2500_Init( SPI_HandleTypeDef* hspi )
{
    //CC2500_STATUS cc2500Status;
    //cc2500Status.StatusByte = 0;
    
    if (!CC2500_Reset(hspi))
        return false;
    
    CC2500_CS_DISABLE();
    
    CC2500_Write_Register(hspi, CC2500_IOCFG0      ,0x00);	
    CC2500_Write_Register(hspi, CC2500_IOCFG1      ,0x00);	
    CC2500_Write_Register(hspi, CC2500_IOCFG2      ,0x06);	//pin GDO2 se nastavi pri odeslani/prijet SYNC a resetuje po odvysilani
    CC2500_Write_Register(hspi, CC2500_FIFOTHR     ,0x08);	//prah zaplneni FIFO - v soucasne dobe nepotrebny
    CC2500_Write_Register(hspi, CC2500_PKTCTRL0    ,0x45);	//promenna delka, nasobeni s pseudonahodou sekvenci - dochazelo ke strate synchronizace pri nulovych paketech
    CC2500_Write_Register(hspi, CC2500_PKTLEN      ,0x78);	//maximani povolena delka paketu 120 - nepouziva se
    CC2500_Write_Register(hspi, CC2500_PKTCTRL1    ,0x00);  //pro test 0x04-posilat RSSI a LQI
    CC2500_Write_Register(hspi, CC2500_FSCTRL1     ,0x10);  
    CC2500_Write_Register(hspi, CC2500_FREQ2   	 ,0x5C);	
    CC2500_Write_Register(hspi, CC2500_FREQ1   	 ,0x60);	
    CC2500_Write_Register(hspi, CC2500_FREQ0   	 ,0x7E);	
    CC2500_Write_Register(hspi, CC2500_MDMCFG4 	 ,0x0E);	
    CC2500_Write_Register(hspi, CC2500_MDMCFG3 	 ,0x3B);	
    CC2500_Write_Register(hspi, CC2500_MDMCFG2 	 ,0x73);	
    CC2500_Write_Register(hspi, CC2500_MDMCFG1 	 ,0x43);	
    CC2500_Write_Register(hspi, CC2500_MDMCFG0 	 ,0x84);	
    CC2500_Write_Register(hspi, CC2500_CHANNR 	 ,0x00);
    CC2500_Write_Register(hspi, CC2500_DEVIATN 	 ,0x00);	
    CC2500_Write_Register(hspi, CC2500_MCSM0   	 ,0x08);	//nekalibrovat(IDLE to RX,TX)
    CC2500_Write_Register(hspi, CC2500_FOCCFG  	 ,0x1D);	
    CC2500_Write_Register(hspi, CC2500_BSCFG   	 ,0x1C);	
    CC2500_Write_Register(hspi, CC2500_AGCCTRL2	 ,0xC7);	
    CC2500_Write_Register(hspi, CC2500_AGCCTRL0	 ,0xB0);	
    CC2500_Write_Register(hspi, CC2500_FREND1  	 ,0xB6);	
    CC2500_Write_Register(hspi, CC2500_FSCAL3  	 ,0xEA);	
    CC2500_Write_Register(hspi, CC2500_FSCAL1  	 ,0x00);	
    CC2500_Write_Register(hspi, CC2500_FSCAL0  	 ,0x19);	
    
  
      
    CC2500_Send_Strobe_Command(hspi, CC2500_STROBE_SFTX);   // fflush TX FIFO      
    CC2500_Send_Strobe_Command(hspi, CC2500_STROBE_SFRX);   // fflush RX FIFO
    CC2500_Write_PATABLE(hspi);
   
    if (CC2500_CalibrateFrequencies(hspi)==false)
    {
        return false;
    }
    
    CC2500_Channel_Change(hspi, 60);
    //Wait_undef(3000);
    HAL_Delay(1);
    
    
//    ConfigINT1(EXT_INT_PRI_5 |             // configure INT1, disable interrupt
//               RISING_EDGE_INT |
//               EXT_INT_DISABLE);
//    
//    ConfigINT2(EXT_INT_PRI_5 |             // configure INT2, enable interrupt
//               FALLING_EDGE_INT |
//               EXT_INT_DISABLE);
   
    
    return true;
}


uint8_t CC2500_Status_Update( SPI_HandleTypeDef* hspi )
{
    uint8_t RetData = 0;
    RetData = CC2500_Send_Strobe_Command(hspi, CC2500_STROBE_SNOP);
    return RetData;
}

#define    RSSIoffset 72 
uint8_t RSSI2dBm(uint8_t RSSI)
{
    if (RSSI>=128)
    {
        return -(((uint16_t)RSSI-256)/2-RSSIoffset);
    }else{
        return -(((uint16_t)RSSI)/2-RSSIoffset);
    }
}

//void CC2500_Measure_Background(uint8_t *dBm)
//{
//    CC2500_STATUS State;
//    static uint8_t channelscan=0;
//    static uint8_t RSSI,dBmtmp,power;
//    //UINT16 measureCounter=10000;
//    CC2500_Channel_Change(channelscan);

//    //CC2500_Write_Register(CC2500_MDMCFG2 	 ,0x70);	//ZMENA puv 0x73
//    CC2500_RX_Enable();
//    DisableINT1;
//    DisableINT2;
//    
//    *(dBm+channelscan) = 255;
//    while(1)
//    {
//        if (mCTGetIntFlag()==0)
//        {
//            RSSI = CC2500_Read_Register(CC2500_RSSI);
//            power = RSSI2dBm(RSSI);
//            dBmtmp = *(dBm + channelscan);
//            if (power < dBmtmp)
//            {
//                *(dBm+channelscan) = power;
//            }
//                
//            State.StatusByte = CC2500_Send_Strobe_Command(CC2500_STROBE_SNOP);
//            if((State.StatusBits.STATE == CC2500_IDLE) || (State.StatusBits.STATE == RX_FIFO_OVERFLOW))
//            {
//                CC2500_RX_Enable();
//                DisableINT1;
//                DisableINT2;
//            }
//        }else{
//            mCTClearIntFlag();
//            UpdateCoreTimer(10000000);
//            
//            CC2500_Channel_Change(++channelscan);
//            mPORTDToggleBits(BIT_3);
//            if(channelscan==0)                              //proskenovano vse
//            {
//                break;
//            }
//            *(dBm+channelscan) = 255;
//        }
//    }
//    
//}

bool CC2500_Write_Register(SPI_HandleTypeDef* hspi, CC2500Registers_Enum Reg, uint8_t Data)
{
    uint8_t TxBuff[2];
    uint8_t RxBuff[2];
    
    if (Reg > CC2500_TEST0) return false;
    TxBuff[0] = (Reg & ~READ_SINGLE);   //write only (0x7F)
    TxBuff[1] = Data;

    CC2500_SPI_Comm(hspi, TxBuff, RxBuff, 2);
    
    return true;
}	


static void CC2500_Write_PATABLE( SPI_HandleTypeDef* hspi)
{
    uint8_t TxBuff[2];
    uint8_t RxBuff[2];
    
    TxBuff[0] = CC2500_PATABLE | WRITE_SINGLE;
    TxBuff[1] = 0xFF;
    
    CC2500_SPI_Comm(hspi,TxBuff,RxBuff,2);
    
}	

uint8_t CC2500_Read_Register(SPI_HandleTypeDef* hspi, CC2500Registers_Enum reg)
{
    uint8_t TxBuff[2];
    uint8_t RxBuff[2];
    
    if (reg <=CC2500_TEST0) TxBuff[0] = (reg | READ_SINGLE);
    else TxBuff[0] = (reg | READ_BURST);                          //burst mode
    TxBuff[1] = 0xFF;

    CC2500_SPI_Comm(hspi,TxBuff,RxBuff,2);

    return RxBuff[1];
}	


uint8_t CC2500_Send_Strobe_Command(SPI_HandleTypeDef* hspi, CC2500StrobeCommands_Enum Command)
{
    uint8_t TxBuff[2];
    uint8_t RxBuff[2];
    
    TxBuff[0] = Command & ~WRITE_BURST; //0xBF;    // set Burst bit to  zero                 

    CC2500_SPI_Comm(hspi,TxBuff,RxBuff,1);
    return RxBuff[0];
}


static uint8_t CC2500_Get_TX_FIFO_Bytes_Available( SPI_HandleTypeDef* hspi )
{
    uint8_t RetVal2;
    RetVal2 = CC2500_Read_Register(hspi, CC2500_TXBYTES);
    return RetVal2;
}


static uint8_t CC2500_Get_RX_FIFO_Bytes_Available( SPI_HandleTypeDef* hspi )
{   
    uint8_t RetVal2;
    RetVal2 = CC2500_Read_Register(hspi, CC2500_RXBYTES);
    return RetVal2;
}



/*******************************************************************************
 * CC2500_RX_Enable - Zapne prijimaci rezim radia 
 * pameti
 * vstup    typ radia
 *          ukazatel na pole data 
 *          Delka pole 
 * vystup   NA
*******************************************************************************/
void    CC2500_RX_Enable(SPI_HandleTypeDef* hspi )
{
    CC2500Status = CC2500_RX_ENABLED;
    //SYS_INT_ExternalInterruptTriggerSet(INT_EXTERNAL_INT_SOURCE1,INT_EDGE_TRIGGER_RISING);

////    DisableINT1;
////    DisableINT2;
////    
////  
////    EnableINT1;
////    EnableINT2;
    CC2500_Write_Register(hspi, CC2500_IOCFG0,GDO_RXFIFO_ABOVE_THR_OR_END_OF_PACKET);     //change GDOx_CFG
    //UINT8 regr = CC2500_Read_Register(CC2500_IOCFG0);
    CC2500_Send_Strobe_Command(hspi, CC2500_STROBE_SIDLE);
    CC2500_Send_Strobe_Command(hspi, CC2500_STROBE_SFRX);   // flush RX FIFO   
////    INTCONbits.INT1EP = 1;                              //zmena detekce hrany na rising edge 
////    
////    oldGDO0 = mPORTEReadBits(BIT_8)>>8;
////    oldGDO2 = mPORTEReadBits(BIT_9)>>9;
     
    CC2500_Send_Strobe_Command(hspi, CC2500_STROBE_SRX);    // enable RX mode    
}
/*******************************************************************************
 * CC2500_TXRX_Off - Prepne radio do stavu Idle 
 * pameti
 * vstup    typ radia
 *          ukazatel na pole data 
 *          Delka pole 
 * vystup   NA
*******************************************************************************/
void    CC2500_TXRX_Off(SPI_HandleTypeDef* hspi)
{
    CC2500_Send_Strobe_Command(hspi,CC2500_STROBE_SIDLE);
    CC2500Status = CC2500_IDLE;
    
}
/*******************************************************************************
 * CC2500_Get_State
 *******************************************************************************/

uint8_t CC2500_Get_State(SPI_HandleTypeDef* hspi, uint8_t read_write)
{
    uint8_t RetVal;
    CC2500StrobeCommands_Enum command = (CC2500StrobeCommands_Enum)(CC2500_STROBE_SNOP|read_write); //0x80
    RetVal = CC2500_Send_Strobe_Command(hspi,  command);
    return RetVal;
}

/*******************************************************************************
 * CC2500_Reset - Resetuje CC2500, registry a stavy 
 * pameti
 * vstup    NA
 * vystup   NA
*******************************************************************************/
uint8_t CC2500_Reset( SPI_HandleTypeDef* hspi )
{
    CC2500_STATUS State;
    uint16_t timeout = 100;
    
    CC2500_CS_DISABLE();
    HAL_Delay(1);
    //Wait_undef(1000);
    CC2500_CS_ENABLE();
    HAL_Delay(1);
    //Wait_undef(80);
    CC2500_CS_DISABLE();
    HAL_Delay(1);
    //Wait_undef(300);
    CC2500_CS_ENABLE();
    
//////    while( mPORTFReadBits(BIT_8)==BIT_8 );
    
    CC2500_Send_Strobe_Command(hspi, CC2500_STROBE_SRES);
    //Wait_undef(6000);
    HAL_Delay(1);
    do
    {
        State.StatusByte = CC2500_Send_Strobe_Command(hspi, CC2500_STROBE_SNOP);
        timeout--;
    }
    while ((State.StatusBits.STATE != CC2500_IDLE) && (timeout !=0));
    if (timeout != 0)
        return 1;
    else
        return 0;
            
}

/*******************************************************************************
 * CC2500_SendVariablePacket - odesle data o delce PacketLen z &Data
 * vstup    ukazatel na pole data 
 *          Delka pole 
 * vystup   NA
 * 
 *          PRO dlouhe pakety (>63B)
 *          JE TREBA UMISTIT DO ISR PRO GD0 s parametrem PacketLen -1 !!!
 * 
*******************************************************************************/
uint8_t CC2500_SendVariablePacket( SPI_HandleTypeDef* hspi, uint8_t *Data, int8_t PacketLen)
{
    static int8_t RemainingLen;
    static uint8_t *data;
    uint8_t CommandLengh = 2;

        
    if (PacketLen != -1)
    {
        CC2500_TXRX_Off(hspi);   
        RemainingLen=PacketLen;
        data=Data;

        CC2500_Write_Register(hspi, CC2500_IOCFG0,GDO_TXFIFO_ABOVE_THR_DEASERT_BELLOW);     //change GDOx_CFG
        CC2500_Send_Strobe_Command(hspi, CC2500_STROBE_SFTX);                               //flush FIFO TX buffer
        
        TxFIFO[1]=PacketLen;                                                            //delka paketu [B]
    }else{
        if (CC2500Status == TX_MODE_ENABLED)                    //volani z interruptu
        {
            CommandLengh = 1;                                   //nepridavat delku paketu jako prvni byte,pokracovani packetu
        }else{
            return 0;                                           //volan z interuptu ale nevysila se
        }    
    }
    memcpy(TxFIFO+2,Data,10);
    TxFIFO[0]=CC2500_FIFO | WRITE_BURST;                        //adresa write FIFO
    
    if(RemainingLen >= 63)                                           //rozdelit packet pokud je vetsi nez FIFO - 1B (delka packetu)
    {
        CC2500Status = TX_MODE_ENABLED;

        //TxBuff
        
        CC2500_SPI_Comm_DMA(hspi, &TxFIFO[0], &RxFIFO[0],RemainingLen + CommandLengh);     //prikaz a zapsat delku na pozici prvniho bytu

        RemainingLen -=63;                                                          //odeslano 63B, zbyva odelsat o 63B mene
        data+=63;                                                              //posunout ukazatel
        
    }else{
        
        if (RemainingLen <= 32)
        {
            CC2500_SPI_Comm_DMA(hspi, &TxFIFO[0], &RxFIFO[0], RemainingLen + CommandLengh);     //4. cast 115B paketu, maly 32B paket
            RemainingLen = 0;
            CC2500Status = CC2500_FINISHING_TRANSMISSON;
        }else{
            CC2500_SPI_Comm(hspi, &TxFIFO[0], &RxFIFO[0], CommandLengh);     //2. cast paketu velkeho paketu, maly paket
            CC2500_SPI_Comm(hspi, data, &RxFIFO[0], 32);
            RemainingLen -=32;
            data+=32;
        }  
    }
    
    CC2500_TX_Enable(hspi);
    //CC2500_Send_Strobe_Command(CC2500_STROBE_STX);
}

void CC2500_VariablePacketSent(void)                                                    //volano z preruseni pri ukoncen vyslan
{                                                                                //zavola funkci registrovanou v RegisterVariablePacketSentCallback
    if(CC2500Status == CC2500_FINISHING_TRANSMISSON)
    {
        if( VariablePacketSentcallback != NULL)
        {
            (*VariablePacketSentcallback)();
        }
        
    }
}
void RegisterVariablePacketSentCallback(void (*PacketSentCallback)(void))       //registruje fuknci pro ISR pri dokoncen vyslan
{
    VariablePacketSentcallback = PacketSentCallback;
}



/*******************************************************************************
 * CC2500_ReceiveVariablePacketWeapon - vycita data z FIFO
 * vstup    slouzi pro urceni zdroje volani 
 * vystup   NA
 * 
 *          JE TREBA UMISTIT DO ISR PRO GD0 s parametrem CC2500_GDO0 !!!
 *          JE TREBA UMISTIT DO ISR PRO GD2 s parametrem CC2500_GDO2 !!!
 * 
*******************************************************************************/
uint8_t CC2500_ReceiveVariablePacketMastermodul( SPI_HandleTypeDef* hspi,  uint8_t GDO_source)
{
    uint8_t DataAvailable;
    static uint8_t PacketLen;
    //uint8_t TxData[1];
    //static uint8_t testcnt;
    //static uint8_t *testZmena;
        
    if ((CC2500Status != CC2500_RX_ENABLED))
    {
        return 0;
    }else{
        //ByteCounter = 1;                            //na nulte pozici je command byte
        DataAvailable = CC2500_Get_RX_FIFO_Bytes_Available(hspi );
        if ( (DataAvailable==0) | (DataAvailable > 64) )
        {
            //CC2500Status = CC2500_IDLE;
            CC2500_RX_Enable(hspi );
            return 0;
        }
        TxFIFO[0] = CC2500_FIFO | READ_BURST;
        //CC2500_CS_ENABLE();                                                             //DataAvailable + 1 => command byte (pro spi)
        CC2500Status = CC2500_PACKET_RECEIVEING;
        CC2500_SPI_Comm_DMA(hspi,&TxFIFO[0], &RxFIFO[0], DataAvailable + 1);     //zapsat prikaz pro cteni RxFIFO[0]
        //CC2500_CS_DISABLE();                                                                     
    }
}







































/*****************************************************************************************************************/
/*****************************************************************************************************************/
/*****************************************************************************************************************/
/*****************************************************************************************************************/
/*****************************************************************************************************************/
//uint8_t cc2500_Write_Byte_No_CS(uint8_t Byte)
//{
//    uint8_t ReturnVal;
//    DRV_SPI3_BufferAddWriteRead(&Byte, &ReturnVal, 1);
//    return ReturnVal;
//}



/*******************************************************************************
 * CC2500_TX_Enable - Zapne vysilaci rezim radia
 * pameti
 * vstup    typ radia
 *          ukazatel na pole data 
 *          Delka pole 
 * vystup   NA
*******************************************************************************/
void    CC2500_TX_Enable(SPI_HandleTypeDef* hspi)
{
    
    CC2500_Send_Strobe_Command(hspi, CC2500_STROBE_STX);
}




//void CC2500_Write_FIFO_Burst(uint8_t* Data,uint8_t DataLen)
//{
//    uint8_t TxData[2];
//    uint8_t RxData[64];
//    //TxData[0] = 0x7F;

//    TxData[0]=CC2500_FIFO | WRITE_BURST;               //adresa FIFO
//    CC2500_CS_ENABLE();

//#define PACKET_FIXED
//#ifndef PACKET_FIXED
//    TxData[1]=DataLen;                                          //delka paketu [B]
//    DRV_SPI0_BufferAddWriteRead(&TxData[0], &RxData[0], 2);     //prikaz a zapsat delku na pozici prvniho bytu
//#else
//    DRV_SPI3_BufferAddWriteRead(&TxData[0], &RxData[0], 1);
//#endif
//    
//    DRV_SPI3_BufferAddWriteRead(Data, &RxData[0], DataLen);
//    CC2500_CS_DISABLE();
//}	
